@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAtributes, ConvertToDlString
+from RFEM.initModel import Model, clearAttributes, ConvertToDlString
 from RFEM.enums import SurfaceSetLoadType, SurfaceSetLoadDirection, SurfaceSetLoadDistribution, SurfaceSetLoadAxisDefinitionType
 
 class SurfaceSetLoad():
@@ -25,7 +25,7 @@ class SurfaceSetLoad():
         clientObject = model.clientModel.factory.create('ns0:surface_set_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Load No.
         clientObject.no = no
@@ -100,7 +100,7 @@ class SurfaceSetLoad():
         clientObject = model.clientModel.factory.create('ns0:surface_set_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Load No.
         clientObject.no = no
@@ -226,7 +226,7 @@ class SurfaceSetLoad():
         clientObject = model.clientModel.factory.create('ns0:surface_set_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Load No.
         clientObject.no = no
@@ -335,7 +335,7 @@ class SurfaceSetLoad():
         clientObject = model.clientModel.factory.create('ns0:surface_set_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Load No.
         clientObject.no = no
@@ -413,7 +413,7 @@ class SurfaceSetLoad():
         clientObject = model.clientModel.factory.create('ns0:surface_set_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Load No.
         clientObject.no = no
@@ -473,7 +473,7 @@ class SurfaceSetLoad():
         clientObject = model.clientModel.factory.create('ns0:surface_set_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Load No.
         clientObject.no = no
@@ -546,7 +546,7 @@ class SurfaceSetLoad():
         clientObject = model.clientModel.factory.create('ns0:surface_set_load')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Load No.
         clientObject.no = no
