@@ -1,11 +1,11 @@
 from http import client
-from RFEM.initModel import Model, clearAtributes
+from RFEM.initModel import Model, clearAttributes
 from RFEM.enums import *
 
 class MemberEccentricity():
     def __init__(self,
                  no: int = 1,
-                 name: list = [False],
+                 name: str = '',
                  eccentricity_type = MemberEccentricitySpecificationType.TYPE_RELATIVE,
                  eccentricity_parameters: list = [MemberEccentricityHorizontalSectionAlignment.ALIGN_MIDDLE, MemberEccentricityVerticalSectionAlignment.ALIGN_MIDDLE],
                  transverse_offset_type = MemberEccentricityTransverseOffsetType.TRANSVERSE_OFFSET_TYPE_NONE,
@@ -46,18 +46,15 @@ class MemberEccentricity():
         clientObject = model.clientModel.factory.create('ns0:member_eccentricity')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Member Eccentricity No.
         clientObject.no = no
 
         # User Defined Name
-        if name[0]:
+        if name:
             clientObject.user_defined_name_enabled = True
-            clientObject.name = name[1]
-        else:
-            clientObject.user_defined_name_enabled = False
-
+            clientObject.name = name
 
         # Eccentricity Specification Type
         clientObject.specification_type = eccentricity_type.name
